{ config, pkgs, ... }:

{
	home = {
		username = "tacocat";
		homeDirectory = "/home/tacocat";
		stateVersion = "23.11";
		sessionVariables = {
			EDITOR = "lvim";
		};
		packages = with pkgs; [
			wineWowPackages.unstable
		];
	};


	programs.kitty = {
		enable = true;
		package = pkgs.runCommandLocal "no-kitty" {} "mkdir $out";
		# use kitty provided by your distro's package manager
		# can cause weird behaviour if anyhting depends on this package
		font.name = "FiraCode Nerd Font Mono";
		# font.package = pkgs.maple-mono-NF;
		font.package = pkgs.nerdfonts.override {fonts = ["FiraCode"];};
		font.size = 12.0;
		shellIntegration.enableZshIntegration = true;
		theme = "Rosé Pine Moon";
		settings = {
			cursor = "none";
			cursor_shape = "block";
			cursor_blink_interval = 0;
			shell = "zsh";
			shell_integration = "no-cursor";
			background_opacity = "0.9";
			tab_bar_style = "powerline";
			tab_separator = " |";
			tab_powerline_style = "slanted";
			enable_audio_bell = "no";
			# allow_remote_control = "password";
			update_check_interval = 0;
			linux_display_server = "wayland";
		};
		keybindings = {
			"kitty_mod+b" = "select_tab";
		};
	};

	# gtk = {
	# 	enable = true;
	# 	theme.package = pkgs.adw-gtk3;
	# 	theme.name = "adw-gtk3";
	# };

  # Home Manager needs a bit of information about you and the paths it should
  # manage.
  # home.username = "tacocat";
  # home.homeDirectory = "/home/tacocat";

  # This value determines the Home Manager release that your configuration is
  # compatible with. This helps avoid breakage when a new Home Manager release
  # introduces backwards incompatible changes.
  #
  # You should not change this value, even if you update Home Manager. If you do
  # want to update the value, then make sure to first check the Home Manager
  # release notes.
  # home.stateVersion = "23.05"; # Please read the comment before changing.

  # The home.packages option allows you to install Nix packages into your
  # environment.
  # home.packages = [
    # # Adds the 'hello' command to your environment. It prints a friendly
    # # "Hello, world!" when run.
    # pkgs.hello

    # # It is sometimes useful to fine-tune packages, for example, by applying
    # # overrides. You can do that directly here, just don't forget the
    # # parentheses. Maybe you want to install Nerd Fonts with a limited number of
    # # fonts?
    # (pkgs.nerdfonts.override { fonts = [ "FantasqueSansMono" ]; })

    # # You can also create simple shell scripts directly inside your
    # # configuration. For example, this adds a command 'my-hello' to your
    # # environment:
    # (pkgs.writeShellScriptBin "my-hello" ''
    #   echo "Hello, ${config.home.username}!"
    # '')
  # ];

  # Home Manager is pretty good at managing dotfiles. The primary way to manage
  # plain files is through 'home.file'.
  # home.file = {
    # # Building this configuration will create a copy of 'dotfiles/screenrc' in
    # # the Nix store. Activating the configuration will then make '~/.screenrc' a
    # # symlink to the Nix store copy.
    # ".screenrc".source = dotfiles/screenrc;

    # # You can also set the file content immediately.
    # ".gradle/gradle.properties".text = ''
    #   org.gradle.console=verbose
    #   org.gradle.daemon.idletimeout=3600000
    # '';
  # };

  # You can also manage environment variables but you will have to manually
  # source
  #
  #  ~/.nix-profile/etc/profile.d/hm-session-vars.sh
  #
  # or
  #
  #  /etc/profiles/per-user/tacocat/etc/profile.d/hm-session-vars.sh
  #
  # if you don't want to manage your shell through Home Manager.
  # home.sessionVariables = {
    # EDITOR = "lvim";
  # };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;
}
